#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ROR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ROR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/ror.hpp>

#endif
